<?php
function it_exchange_product_importer_product_fields() {

	$fields = array();
	$fields[] = array(
		'name' => 'product_title',
		'label' => __( 'Product Title', 'exchange-addon-importer' ),
		'alias' => array( 'product_name', 'name', 'title' )
	);
	$fields[] = array(
		'name' => 'description',
		'label' => __( 'Description', 'exchange-addon-importer' )
	);
	$fields[] = array(
		'name' => 'extended_description',
		'label' => __( 'Extended Description', 'exchange-addon-importer' ),
		'alias' => array( 'additional_description' )
	);
	$fields[] = array(
		'name' => 'price',
		'label' => __( 'Price', 'exchange-addon-importer' )
	);
	$fields[] = array(
		'name' => 'product_type',
		'label' => __( 'Product Type', 'exchange-addon-importer' ),
		'alias' => array( 'type' )
	);
	$fields[] = array(
		'name' => 'visibility',
		'label' => __( 'Visibility', 'exchange-addon-importer' )
	);
	// Check that the Product Categories add-on is enabled
	$term_taxonomy = 'it_exchange_category';
	if( taxonomy_exists( $term_taxonomy ) ) {
		$fields[] = array(
			'name' => 'category',
			'label' => __( 'Category', 'exchange-addon-importer' )
		);
	}
	// Check that the Product Tags add-on is enabled
	$term_taxonomy = 'it_exchange_tag';
	if( taxonomy_exists( $term_taxonomy ) ) {
		$fields[] = array(
			'name' => 'tag',
			'label' => __( 'Tag', 'exchange-addon-importer' )
		);
	}
	$fields[] = array(
		'name' => 'inventory',
		'label' => __( 'Inventory', 'exchange-addon-importer' ),
		'alias' => array( 'quantity' )
	);
	$fields[] = array(
		'name' => 'purchase_message',
		'label' => __( 'Purchase Message', 'exchange-addon-importer' )
	);
	$fields[] = array(
		'name' => 'status',
		'label' => __( 'Product Status', 'exchange-addon-importer' )
	);
	$fields[] = array(
		'name' => 'store_order',
		'label' => __( 'Store Order', 'exchange-addon-importer' )
	);
	$fields[] = array(
		'name' => 'slug',
		'label' => __( 'Slug', 'exchange-addon-importer' )
	);

/*
	Sample
	$fields[] = array(
		'name' => 'sample',
		'label' => __( 'Sample Product Meta', 'exchange-addon-importer' )
	);
*/

	// Add Product SKU - http://wordpress.org/plugins/exchange-addon-add-product-sku/
	if( it_exchange_product_type_supports_feature( 'simple-product-type', 'sku' ) ) {
		$field[0] = array(
			'name' => 'sku',
			'label' => __( 'SKU', 'exchange-addon-importer' )
		);
		$fields = array_merge( $field, $fields );
		unset( $field );
	}
	return $fields;

}

function it_exchange_product_importer_prepare_product( $count ) {

	global $import, $product;

	$product = new stdClass;

	// Set up empty vars
	$product->skipped = false;
	$product->duplicate_exists = false;

	$product->sku = ( isset( $import->csv_sku[$count] ) ? $import->csv_sku[$count] : null );
	it_exchange_product_importer_duplicate_product_exists();
	$product->product_title = ( isset( $import->csv_product_title[$count] ) ? wp_strip_all_tags( $import->csv_product_title[$count] ) : '' );
	$product->description = ( isset( $import->csv_description[$count] ) ? html_entity_decode( $import->csv_description[$count] ) : null );
	$product->extended_description = ( isset( $import->csv_extended_description[$count] ) ? html_entity_decode( $import->csv_extended_description[$count] ) : null );
	$product->price = ( isset( $import->csv_price[$count] ) ? it_exchange_product_importer_is_valid_price( $import->csv_price[$count] ) : null );
	$product->product_type = ( isset( $import->csv_product_type[$count] ) ? it_exchange_product_importer_is_valid_product_type( $import->csv_product_type[$count] ) : null );
	$product->visibility = ( isset( $import->csv_visibility[$count] ) ? it_exchange_product_importer_is_valid_visibility( $import->csv_visibility[$count] ) : null );
	$product->category = ( isset( $import->csv_category[$count] ) ? $import->csv_category[$count] : null );
	$product->tag = ( isset( $import->csv_tag[$count] ) ? $import->csv_tag[$count] : null );
	$product->inventory = ( isset( $import->csv_inventory[$count] ) ? it_exchange_product_importer_is_valid_quantity( $import->csv_inventory[$count] ) : null );
	$product->purchase_message = ( isset( $import->csv_purchase_message[$count] ) ? $import->csv_purchase_message[$count] : null );
	$product->status = ( isset( $import->csv_status[$count] ) ? it_exchange_product_importer_is_valid_status( $import->csv_status[$count] ) : null );
	$product->store_order = ( isset( $import->csv_store_order[$count] ) ? $import->csv_store_order[$count] : null );
	$product->slug = ( isset( $import->csv_slug[$count] ) ? wp_unique_post_slug( sanitize_title( $import->csv_slug[$count] ) ) : null );

	// Allow Plugin/Theme authors to add support for additional Product details
	$product = apply_filters( 'it_exchange_product_importer_product_addons', $product, $import, $count );

	// $product->sample = ( isset( $import->csv_sample[$count] ) ? $import->csv_sample[$count] : null );

}

function it_exchange_product_importer_duplicate_product_exists() {

	global $product;

	$product->duplicate_exists = false;
	$post_type = 'it_exchange_prod';

	// Check for duplicate Product by SKU if present
	if( !empty( $product->sku ) ) {
		$meta_key = '_it-exchange-product-sku';
		$args = array(
			'post_type' => $post_type,
			'meta_key' => $meta_key,
			'meta_value' => $product->sku,
			'numberposts' => 1,
			'fields' => 'ids'
		);
		$products = new WP_Query( $args );
		if( !empty( $products->posts ) )
			$product->duplicate_exists = $products->posts[0];
	// Check for duplicate Product by Product Title if SKU is not present
	} else if( !empty( $product->product_title ) ) {
		$products = get_page_by_title( $product->product_title, null, $post_type );
		if( get_post_status( $products->ID ) !== false )
			$product->duplicate_exists = $products->ID;
	}
	unset( $products );

}

function it_exchange_product_importer_is_valid_product_type( $product_type = '' ) {

	$output = null;
	// Let's make the Product Type easy to filter
	$product_type = str_replace( array( ' ', '_' ), '-', strtolower( $product_type ) );
	switch( $product_type ) {

		case 'simple':
		case 'simple-products':
		case 'simple-product':
		default:
			$output = 'simple-product-type';
			break;

		case 'physical':
		case 'physical-products':
		case 'physical-product':
			$output = 'physical-product-type';
			break;

		case 'digital':
		case 'digital-downloads':
		case 'digital-download':
			$output = 'digital-downloads-product-type';
			break;

	}
	return $output;

}

function it_exchange_product_importer_is_valid_visibility( $visibility = '' ) {

	$output = null;
	// Let's make the Visibility easy to filter
	$visibility = str_replace( array( ' ', '_' ), '-', strtolower( $visibility ) );
	switch( $visibility ) {

		case 'visible':
		case 'show':
		case 'show-in-store':
		default:
			$output = 'visible';
			break;

		case 'hidden':
		case 'hide':
		case 'hide-from-store':
			$output = 'hidden';
			break;

	}
	return $output;

}

function it_exchange_product_importer_is_valid_quantity( $quantity = '' ) {

	$quantity = strtolower( $quantity );
	switch( $quantity ) {

		case 'n/a':
		case '-':
			return false;
			break;

		default:
			return $quantity;

	}

}

function it_exchange_product_importer_is_valid_price( $price = '' ) {

	// Need to add validation and formatting of prices
	return $price;

}

function it_exchange_product_importer_validate_product() {

	global $import, $product;

	$status = false;
	$product->fail_requirements = false;
	if( $import->import_method == 'new' ) {
		// Create new Product - Requires Name and no existing Product
		if( empty( $product->product_title ) || $product->duplicate_exists )
			$status = true;
	} else if( $import->import_method == 'delete' ) {
		// Delete matching Product - Requires an existing Product
		if( !$product->duplicate_exists )
			$status = true;
	}
	if( $status ) {
		$import->fail_requirements = true;
		$product->fail_requirements = true;
		$failed_reason = array();
		if( $import->import_method == 'new' ) {
			if( empty( $product->product_title ) )
				$failed_reason[] = __( 'No Product Title was provided.', 'exchange-addon-importer' );
			if( $product->duplicate_exists )
				$failed_reason[] = __( 'A duplicate SKU already exists.', 'exchange-addon-importer' );
		} else if( $import->import_method == 'delete' ) {
			if( !$product->duplicate_exists )
				$failed_reason[] = __( 'No matching Product could be found.', 'exchange-addon-importer' );
		}
		if( empty( $failed_reason ) )
			$failed_reason[] = __( 'No specific reason was given, raise this as a Support issue.', 'exchange-addon-importer' );
		$import->failed_products[] = array( 
			'sku' => $product->sku,
			'product_title' => $product->product_title,
			'category' => str_replace( $import->category_separator, "<br />", str_replace( $import->parent_child_delimiter, ' &raquo; ', $product->category ) ),
			'reason' => $failed_reason 
		);
		return true;
	}

}

function it_exchange_product_importer_create_product() {

	global $wpdb, $product, $import, $user_ID;

	$post_type = 'it_exchange_prod';
	$post_data = array(
		'post_author' => $user_ID,
		'post_date' => current_time( 'mysql' ),
		'post_date_gmt' => current_time( 'mysql', 1 ),
		'post_title' => ( !is_null( $product->product_title ) ? $product->product_title : '' ),
		'post_name' => ( !is_null( $product->slug ) ? $product->slug : null ),
		'post_status' => 'publish',
		'comment_status' => 'closed',
		'ping_status' => 'closed',
		'post_type' => $post_type,
		'post_content' => ( !is_null( $product->extended_description ) ? $product->extended_description : '' ),
		'post_excerpt' => '',
	);
	$product->ID = wp_insert_post( $post_data, true );
	if( is_wp_error( $product->ID ) !== true ) {
		it_exchange_product_importer_create_product_meta_defaults();
		it_exchange_product_importer_create_product_meta_details();
		$import->products_added++;
	} else {
		$product->skipped = true;
	}

}

function it_exchange_product_importer_create_product_meta_defaults() {

	global $import, $product;

	$defaults = array(
		'_it_exchange_product_type' => $import->default_product_type,
		'_it-exchange-visibility' => 'visible',
		'_it-exchange-base-price' => 0,
		'_it-exchange-product-description' => '',
		'_it-exchange-product-enable-inventory' => 'no'
	);
	if( $defaults = apply_filters( 'it_exchange_product_importer_create_product_defaults', $defaults, $product->ID ) ) {
		foreach( $defaults as $key => $default )
			update_post_meta( $product->ID, $key, $default );
	}

}

function it_exchange_product_importer_create_product_meta_details() {

	global $wpdb, $product, $import, $user_ID;

	it_exchange_product_importer_upload_directories();

	// Insert SKU
	if( $product->sku !== null ) {
		update_post_meta( $product->ID, '_it-exchange-product-sku', $product->sku );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting SKU: %s', 'exchange-addon-importer' ), $product->sku );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting SKU', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping SKU', 'exchange-addon-importer' );
	}

	// Insert Price
	if( $product->price !== null ) {
		update_post_meta( $product->ID, '_it-exchange-base-price', ( function_exists( 'it_exchange_convert_to_database_number' ) ? it_exchange_convert_to_database_number( $product->price ) : $product->price ) );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Price: %s', 'exchange-addon-importer' ), $product->price );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Price', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Price', 'exchange-addon-importer' );
	}

	// Insert Description
	if( $product->price !== null ) {
		update_post_meta( $product->ID, '_it-exchange-product-description', $product->description );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Description: %s', 'exchange-addon-importer' ), $product->description );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Description', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Description', 'exchange-addon-importer' );
	}

	// Insert Extended Description
	if( $product->extended_description !== null ) {
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Extended Description: %s', 'exchange-addon-importer' ), $product->extended_description );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Extended Description', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Extended Description', 'exchange-addon-importer' );
	}

	// Insert Product Type
	if( $product->product_type !== null ) {
		update_post_meta( $product->ID, '_it_exchange_product_type', $product->product_type );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Product Type: %s', 'exchange-addon-importer' ), $product->product_type );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Product Type', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Product Type', 'exchange-addon-importer' );
	}

	// Insert Visibility
	if( $product->visibility !== null ) {
		update_post_meta( $product->ID, '_it-exchange-visibility', $product->visibility );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Visibility: %s', 'exchange-addon-importer' ), $product->visibility );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Visibility', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Visibility', 'exchange-addon-importer' );
	}

	// Insert Category
	$term_taxonomy = 'it_exchange_category';
	if( !empty( $product->category_term_id ) && taxonomy_exists( $term_taxonomy ) ) {
		$term_taxonomy_ids = wp_set_object_terms( $product->ID, array_unique( array_map( 'intval', $product->category_term_id ) ), $term_taxonomy );
		if( $import->advanced_log ) {
			if( count( $product->category_term_id ) == 1 )
				$import->log .= "<br />>>>>>> " . sprintf( __( 'Linking Category: %s', 'exchange-addon-importer' ), $product->category );
			else
				$import->log .= "<br />>>>>>> " . sprintf( __( 'Linking Categories: %s', 'exchange-addon-importer' ), $product->category );
		} else {
			if( count( $product->category_term_id ) == 1 )
				$import->log .= "<br />>>>>>> " . __( 'Linking Category', 'exchange-addon-importer' );
			else
				$import->log .= "<br />>>>>>> " . __( 'Linking Categories', 'exchange-addon-importer' );
		}
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Category', 'exchange-addon-importer' );
	}

	// Insert Tag
	$term_taxonomy = 'it_exchange_tag';
	if( !empty( $product->tag_term_id ) && taxonomy_exists( $term_taxonomy ) ) {
		$term_taxonomy_ids = wp_set_object_terms( $product->ID, array_unique( array_map( 'intval', $product->tag_term_id ) ), $term_taxonomy );
		if( $import->advanced_log ) {
			if( count( $product->tag_term_id ) == 1 )
				$import->log .= "<br />>>>>>> " . sprintf( __( 'Linking Tag: %s', 'exchange-addon-importer' ), $product->tag );
			else
				$import->log .= "<br />>>>>>> " . sprintf( __( 'Linking Tags: %s', 'exchange-addon-importer' ), $product->tag );
		} else {
			if( count( $product->tag_term_id ) == 1 )
				$import->log .= "<br />>>>>>> " . __( 'Linking Tag', 'exchange-addon-importer' );
			else
				$import->log .= "<br />>>>>>> " . __( 'Linking Tags', 'exchange-addon-importer' );
		}
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Tag', 'exchange-addon-importer' );
	}

	// Insert Inventory
	if( $product->inventory !== null ) {
		if( $product->inventory == '' ) {
			update_post_meta( $product->ID, '_it-exchange-product-enable-inventory', 'no' );
		} else {
			update_post_meta( $product->ID, '_it-exchange-product-enable-inventory', 'yes' );
			update_post_meta( $product->ID, '_it-exchange-product-inventory', $product->inventory );
		}
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Inventory: %s', 'exchange-addon-importer' ), $product->inventory );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Inventory', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Inventory', 'exchange-addon-importer' );
	}

	// Insert Purchase Message
	if( $product->purchase_message !== null ) {
		update_post_meta( $product->ID, 'it-exchange-product-purchase-message', $product->purchase_message );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Purchase Message: %s', 'exchange-addon-importer' ), $product->purchase_message );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Purchase Message', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Purchase Message', 'exchange-addon-importer' );
	}

	// Insert Product Status
	if( $product->status !== null ) {
		$post_data = array(
			'ID' => $product->ID,
			'post_status' => $product->status
		);
		$response = wp_update_post( $post_data, true );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Product Status: %s', 'exchange-addon-importer' ), $product->status );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Product Status', 'exchange-addon-importer' );
		if( is_wp_error( $response ) ) {
			if( $import->advanced_log )
				$import->log .= "<br />>>>>>>>>> " . sprintf( __( 'Could not set Product Status using wp_update_post(): %s - Error: %s', 'exchange-addon-importer' ), $product->status, $response->get_error_message() );
			else
				$import->log .= "<br />>>>>>>>>> " . __( 'Could not set Product Status using wp_update_post()', 'exchange-addon-importer' );
			it_exchange_product_importer_force_update_post( $product->ID, 'post_status', $product->status );
			if( $import->advanced_log )
				$import->log .= "<br />>>>>>>>>> " . sprintf( __( 'Force set Product Status: %s', 'exchange-addon-importer' ), $product->status );
			else
				$import->log .= "<br />>>>>>>>>> " . __( 'Force set Product Status', 'exchange-addon-importer' );
		}
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Product Status', 'exchange-addon-importer' );
	}

	// Insert Store Order
	if( $product->store_order !== null ) {
		$post_data = array(
			'ID' => $product->ID,
			'menu_order' => $product->store_order
		);
		$response = wp_update_post( $post_data, true );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Store Order: %s', 'exchange-addon-importer' ), $product->store_order );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Store Order', 'exchange-addon-importer' );
		if( is_wp_error( $response ) ) {
			if( $import->advanced_log )
				$import->log .= "<br />>>>>>>>>> " . sprintf( __( 'Could not set Store Order using wp_update_post(): %s - Error: %s', 'exchange-addon-importer' ), $product->store_order, $response->get_error_message() );
			else
				$import->log .= "<br />>>>>>>>>> " . __( 'Could not set Store Order wp_update_post()', 'exchange-addon-importer' );
			it_exchange_product_importer_force_update_post( $product->ID, 'menu_order', $product->store_order );
			if( $import->advanced_log )
				$import->log .= "<br />>>>>>>>>> " . sprintf( __( 'Force set Store Order: %s', 'exchange-addon-importer' ), $product->store_order );
			else
				$import->log .= "<br />>>>>>>>>> " . __( 'Force set Store Order', 'exchange-addon-importer' );
		}
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Store Order', 'exchange-addon-importer' );
	}

	// Insert Slug
	if( $product->slug !== null ) {
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Slug: %s', 'exchange-addon-importer' ), $product->slug );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Slug', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Slug', 'exchange-addon-importer' );
	}

	// Allow Plugin/Theme authors to add support for additional Product details
	$product = apply_filters( 'it_exchange_product_importer_create_product_addons', $product, $import );
	$import = apply_filters( 'it_exchange_product_importer_create_product_log_addons', $import, $product );

	// Insert Sample Product Meta
/*
	if( $product->sample !== null ) {
		update_post_meta( $product->ID, '_sample', $product->sample );
		if( $import->advanced_log )
			$import->log .= "<br />>>>>>> " . sprintf( __( 'Setting Sample Product Meta: %s', 'exchange-addon-importer' ), $product->sample );
		else
			$import->log .= "<br />>>>>>> " . __( 'Setting Sample Product Meta', 'exchange-addon-importer' );
	} else if( $import->advanced_log ) {
		$import->log .= "<br />>>>>>> " . __( 'Skipping Sample Product Meta', 'exchange-addon-importer' );
	}
*/

}

function it_exchange_product_importer_delete_product() {

	global $import, $product;

	$response = wp_delete_post( $product->duplicate_exists, true );
	if( $response )
		$import->products_deleted++;
	else
		$import->products_failed++;

}
?>