<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'ITE_PI_FILE', __FILE__ );
define( 'ITE_PI_DIRNAME', basename( dirname( __FILE__ ) ) );
define( 'ITE_PI_RELPATH', basename( dirname( __FILE__ ) ) . '/' . basename( __FILE__ ) );
if( !defined( 'ITE_PI_PATH' ) )
	define( 'ITE_PI_PATH', plugin_dir_path( __FILE__ ) );
define( 'ITE_PI_PREFIX', 'it_exchange_importer' );
define( 'ITE_PI_PLUGINPATH', WP_PLUGIN_URL . '/' . basename( dirname( __FILE__ ) ) );

// Turn this on to enable additional debugging options within the importer
define( 'ITE_PI_DEBUG', false );

include_once( ITE_PI_PATH . 'includes/common.php' );
include_once( ITE_PI_PATH . 'includes/functions.php' );

if( is_admin() ) {

	/* Start of: WordPress Administration */

	include_once( ITE_PI_PATH . 'includes/admin.php' );

	// Register Product Importer in the list of available WordPress importers
	function it_exchange_product_importer_register_importer() {

		register_importer( 'it_exchange_product_importer', __( 'iThemes Exchange - Product Importer', 'exchange-addon-product-importer' ), __( '<strong>Product Importer</strong> - Import Products, Categories, Tags, Images, Downloads and more into iThemes Exchange from a simple CSV file.', 'exchange-addon-product-importer' ), 'it_exchange_product_importer_html_page' );

	}
	add_action( 'admin_init', 'it_exchange_product_importer_register_importer' );

	function it_exchange_product_importer_admin_init() {

		if( isset( $_GET['import'] ) || isset( $_GET['page'] ) ) {
			if( isset( $_GET['import'] ) ) {
				if( $_GET['import'] == ITE_PI_PREFIX )
					$product_importer = true;
			}
			if( isset( $_GET['page'] ) ) {
				if( $_GET['page'] == 'it-exchange-product-importer' )
					$product_importer = true;
			}
		}
		if( isset( $product_importer ) ) {
			@ini_set( 'memory_limit', WP_MAX_MEMORY_LIMIT );
			it_exchange_product_importer_import_init();
		}

		$action = it_exchange_get_action();
		switch( $action ) {

			// Prompt on Import screen when insufficient memory (less than 64M is allocated)
			case 'dismiss-memory':
				it_exchange_product_importer_update_option( 'memory_notice', 1 );
				$url = add_query_arg( 'action', null );
				wp_redirect( $url );
				exit();
				break;

			// Prompt on Import screen to install Store Exporter
			case 'dismiss-exporter':
				it_exchange_product_importer_update_option( 'exporter_notice', 1 );
				$url = add_query_arg( 'action', null );
				wp_redirect( $url );
				exit();
				break;

			case 'dismiss-add-sku':
				it_exchange_product_importer_update_option( 'sku_notice', 1 );
				$url = add_query_arg( 'action', null );
				wp_redirect( $url );
				exit();
				break;

		}

	}
	add_action( 'admin_init', 'it_exchange_product_importer_admin_init' );

	// HTML templates and form processor for Product Importer screen
	function it_exchange_product_importer_html_page() {

		global $import;

		$action = it_exchange_get_action();
		$title = __( 'Product Importer', 'exchange-addon-product-importer' );
		if( in_array( $action, array( 'upload', 'save' ) ) && !$import->cancel_import ) {
			if( $file = it_exchange_product_importer_get_option( 'csv' ) )
				$title .= ': <em>' . basename( $file ) . '</em>';
		}
		it_exchange_product_importer_template_header( $title );
		switch( $action ) {

			case 'upload':
				it_exchange_product_importer_options_html_page();
				break;

			case 'save':
				it_exchange_product_importer_save_html_page();
				break;

			default:
				it_exchange_product_importer_manage_form();
				break;

		}
		it_exchange_product_importer_template_footer();

	}

	// HTML template for Import screen
	function it_exchange_product_importer_manage_form() {

		$tab = false;
		if( isset( $_GET['tab'] ) )
			$tab = $_GET['tab'];
		// If Skip Overview is set then jump to Export screen
		else if( it_exchange_product_importer_get_option( 'skip_overview', false ) )
			$tab = 'import';
		$url = add_query_arg( 'page', 'it-exchange-product-importer' );

		include_once( ITE_PI_PATH . 'templates/admin/tabs.php' );

	}

	// HTML template for Options screen
	function it_exchange_product_importer_options_html_page() {

		global $import;

		$woo_pd_url = 'http://www.visser.com.au/exchange/plugins/product-importer/';
		$woo_pd_link = sprintf( '<a href="%s" target="_blank">' . __( 'Product Importer Deluxe', 'exchange-addon-importer' ) . '</a>', $woo_pd_url );

		$troubleshooting_url = 'http://www.visser.com.au/woocommerce/documentation/plugins/product-importer-deluxe/usage/';

		if( isset( $import->file ) )
			$file = $import->file;
		else
			$file = array(
				'size' => 0
			);

/*
		if( $file['size'] == 0 ) {
			$message = __( '', 'exchange-addon-importer' );
			it_exchange_product_importer_admin_notice( '' );
			$import->cancel_import = true;
		}
*/

		// Display the opening Import tab if the import fails
		if( $import->cancel_import ) {
			it_exchange_product_importer_manage_form();
			return;
		}

		if( $file ) {
			$upload_dir = wp_upload_dir();
			it_exchange_product_importer_prepare_data();
			$i = 0;
			$import->options = it_exchange_product_importer_product_fields();
			$import->options_size = count( $import->options );
			$first_row = array();
			$second_row = array();
			if( isset( $import->lines ) ) {
				$first_row = str_getcsv( $import->lines[0], $import->delimiter );
				$second_row = str_getcsv( $import->lines[1], $import->delimiter );
			}
			foreach( $first_row as $key => $cell ) {
				for( $k = 0; $k < $import->options_size; $k++ ) {
					if( it_exchange_product_importer_format_column( $import->options[$k]['label'] ) == it_exchange_product_importer_format_column( $cell ) ) {
						$import->skip_first = true;
						break;
					}
				}
				if( !isset( $second_row[$key] ) )
					$second_row[$key] = '';
			}
			$product_types = ( function_exists( 'it_exchange_get_enabled_addons' ) ? it_exchange_get_enabled_addons( array( 'category' => array( 'product-type' ) ) ) : array() );
			include_once( ITE_PI_PATH . 'templates/admin/import_upload.php' );
		}

	}

	// HTML template for Save screen
	function it_exchange_product_importer_save_html_page() {

		global $import;

		// Display the opening Import tab if the import fails
		if( $import->cancel_import ) {
			it_exchange_product_importer_manage_form();
			return;
		} else {
			include_once( ITE_PI_PATH . 'templates/admin/import_save.php' );
		}

	}

	/* End of: WordPress Administration */

}
?>